<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>DinverDCGui::AutocorrViewer</name>
    <message>
        <location filename="../src/AutocorrViewer.cpp" line="47"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AutocorrViewer.cpp" line="49"/>
        <source>Current target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AutocorrViewer.cpp" line="52"/>
        <source>Show/hide the current target onto the inverted autocorrelation curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AutocorrViewer.cpp" line="76"/>
        <source>%1 autocorrelation curves (mode %2):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AutocorrViewer.cpp" line="186"/>
        <source>Ring %1 %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::DCModelViewer</name>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="125"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="128"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="133"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="137"/>
        <source>&amp;Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="141"/>
        <source>&amp;Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="146"/>
        <source>Set &amp;limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="147"/>
        <source>Adjust limits of plots automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="151"/>
        <source>Set default palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="152"/>
        <source>Make the current palette the default one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="180"/>
        <source>Select models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="180"/>
        <source>Select models to create a new plot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="181"/>
        <source>Discard models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DCModelViewer.cpp" line="181"/>
        <source>Discard models to create a new plot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::DispersionViewer</name>
    <message>
        <location filename="../src/DispersionViewer.cpp" line="45"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DispersionViewer.cpp" line="47"/>
        <source>Current target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DispersionViewer.cpp" line="50"/>
        <source>Show/hide the current target onto the inverted dispersion curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DispersionViewer.cpp" line="64"/>
        <source>Dispersion curves (%1 %2):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DispersionViewer.cpp" line="172"/>
        <source>Fundamental mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DispersionViewer.cpp" line="174"/>
        <source>Higher mode %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::EllipticityViewer</name>
    <message>
        <location filename="../src/EllipticityViewer.cpp" line="45"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/EllipticityViewer.cpp" line="47"/>
        <source>Current target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/EllipticityViewer.cpp" line="50"/>
        <source>Show/hide the current target onto the inverted ellipticity curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/EllipticityViewer.cpp" line="67"/>
        <source>Ellipticity curves (%1):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/EllipticityViewer.cpp" line="166"/>
        <source>Fundamental mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/EllipticityViewer.cpp" line="168"/>
        <source>Higher mode %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::GroundModelViewer</name>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="39"/>
        <source>Ground profiles:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="47"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="49"/>
        <source>Add reference model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="50"/>
        <source>Import any .model file and plot its Vp, Vs and density</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="54"/>
        <source>Add Min/Max profiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="55"/>
        <source>Compute the mininum and maximum profiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="61"/>
        <source>Save as report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="62"/>
        <source>Save models and their curves in a .report file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="66"/>
        <source>Export models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="67"/>
        <source>Export profiles in a .model file, e.g. to process them with gpdc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="195"/>
        <source>Export models ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="195"/>
        <source>Model file (*.model)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="199"/>
        <source>Exporting models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="200"/>
        <location filename="../src/GroundModelViewer.cpp" line="250"/>
        <source>Cannot open file for writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="242"/>
        <source>Save as report ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="242"/>
        <source>Report file (*.report)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="244"/>
        <source>Open report for writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GroundModelViewer.cpp" line="249"/>
        <source>Saving as report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::MagnetoTelluricViewer</name>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="45"/>
        <source>Magneto-telluric curves:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="51"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="53"/>
        <source>Current target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="56"/>
        <source>Show/hide the current target onto the inverted magneto-telluric curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="88"/>
        <source>Apparent resistivity (ohm m)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="89"/>
        <source>Apparent conductivity (S/m)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="92"/>
        <source>Phase (degrees)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MagnetoTelluricViewer.cpp" line="93"/>
        <source>1/Phase (1/degrees)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::RefractionViewer</name>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="51"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="53"/>
        <source>Current target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="56"/>
        <source>Show/hide the current target onto the inverted refraction curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="101"/>
        <source>Time (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="104"/>
        <source>Distance (m)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::RefractionVpViewer</name>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="66"/>
        <source>Refraction Vp:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="176"/>
        <source>Source at %1 m</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::RefractionVsViewer</name>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="79"/>
        <source>Refraction Vs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/RefractionViewer.cpp" line="192"/>
        <source>Source at %1 m</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DinverDCGui::ViewerParam</name>
    <message>
        <location filename="../src/ViewerParam.cpp" line="49"/>
        <source>Viewer for selected models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="54"/>
        <source> %1 selected models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="62"/>
        <source>Viewer for non-discarded models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="67"/>
        <source> %1 non-discarded models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="78"/>
        <location filename="../src/ViewerParam.cpp" line="195"/>
        <source>Maximum number of profiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="79"/>
        <source>Ground profiles viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="85"/>
        <location filename="../src/ViewerParam.cpp" line="102"/>
        <location filename="../src/ViewerParam.cpp" line="200"/>
        <location filename="../src/ViewerParam.cpp" line="218"/>
        <source>Maximum number of modes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="86"/>
        <source>Dispersion viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="94"/>
        <location filename="../src/ViewerParam.cpp" line="209"/>
        <source>Maximum number of rings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="95"/>
        <source>Autocorrelation viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="103"/>
        <source>Ellipticity viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="110"/>
        <location filename="../src/ViewerParam.cpp" line="116"/>
        <source>Maximum number of sources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="111"/>
        <source>Refraction Vp viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="117"/>
        <source>Refraction Vs viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="122"/>
        <source>Magneto-telluric viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="334"/>
        <source>Rayleigh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="335"/>
        <source>Love</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="345"/>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="346"/>
        <source>Radial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.cpp" line="347"/>
        <source>Transverse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewerParam</name>
    <message>
        <location filename="../src/ViewerParam.ui" line="27"/>
        <source>Ground profiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="32"/>
        <source>Dispersion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="37"/>
        <source>Autocorrelation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="42"/>
        <source>Ellipticity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="50"/>
        <source>Max N graphs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="90"/>
        <source>Minimum index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A null maximum index is equivalent to no maximum limit.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="100"/>
        <source>Maximum index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="129"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="154"/>
        <source>Signed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="159"/>
        <source>Absolute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="167"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="202"/>
        <source>Polarization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="224"/>
        <source>Frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="229"/>
        <source>Distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="67"/>
        <source>Maximum misfit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="216"/>
        <source>X axis type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="19"/>
        <source>Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="174"/>
        <source>Mode index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="209"/>
        <source>Slowness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="182"/>
        <source>Phase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ViewerParam.ui" line="187"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
